aboutsummaryrefslogtreecommitdiff
path: root/gdb/tm-nindy960.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/tm-nindy960.h')
-rw-r--r--gdb/tm-nindy960.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/gdb/tm-nindy960.h b/gdb/tm-nindy960.h
index 520eb6b..7237278 100644
--- a/gdb/tm-nindy960.h
+++ b/gdb/tm-nindy960.h
@@ -37,12 +37,12 @@ extern int nindy_initial_brk; /* Send a BREAK to reset board first */
extern char *nindy_ttyname; /* Name of serial port to talk to nindy */
#define ADDITIONAL_OPTIONS \
- {"O", 0, &nindy_old_protocol, 1}, \
- {"brk", 0, &nindy_initial_brk, 1}, \
- {"r", 1, 0, 1004}, /* 1004 is magic cookie for ADDL_CASES */
+ {"O", no_argument, &nindy_old_protocol, 1}, \
+ {"brk", no_argument, &nindy_initial_brk, 1}, \
+ {"ser", required_argument, 0, 1004}, /* 1004 is magic cookie for ADDL_CASES */
#define ADDITIONAL_OPTION_CASES \
- case 1004: /* -r option: remote nindy auto-start */ \
+ case 1004: /* -ser option: remote nindy auto-start */ \
nindy_ttyname = optarg; \
break;
@@ -50,7 +50,7 @@ extern char *nindy_ttyname; /* Name of serial port to talk to nindy */
"\
-O Use old protocol to talk to a Nindy target\n\
-brk Send a break to a Nindy target to reset it.\n\
- -r SERIAL Open remote Nindy session to SERIAL port.\n\
+ -ser SERIAL Open remote Nindy session to SERIAL port.\n\
"
/* If specified on the command line, open tty for talking to nindy,